import os,datetime,glob 
import numpy as np 
import matplotlib as mpl 
mpl.use("Agg") 
from pylab import figure, suptitle, subplot, plot, xticks, yticks, legend, xlabel, ylabel, title 
import pycdf 
 
ncDir = '/seacoos/data/nccoos/level1/billymitchell/sodar1' 
ncFileGlob = 'billymitchell_sfas_*.nc' 
 
pngDir = '/seacoos/data/nccoos/level1/billymitchell/sodar1/plots/meanspeed' 
pngExt = 'png' 
htmlExt = 'html' 
 
ncFilePattern = os.path.join(ncDir,ncFileGlob) 
files = glob.glob(ncFilePattern) 
previous = [files[-1]] + files[:-1] 
next = files[1:] + [files[0]] 
files = zip(previous,files,next) 
 
html1 = """<html> 
    <head> 
        <title> 
            Billy Mitchell Sodar :: """ 
 
html2 = """ :: Mean Speed 
        </title> 
    </head> 
    <body>
        <form> 
            <a href=\"""" 
 
html3 = """\">&lt;Previous</a>&nbsp;&nbsp;&nbsp; 
            <a href=\"""" 
 
html4 = """\">Next&gt;</a>
        </form>
        <br/> 
        <img src=\"""" 
 
html5 = """\"> 
    </body> 
</html>""" 
 
first = True 
for previous,ncFile,next in files: 
    print 'Processing',ncFile 
    ncFileName = os.path.splitext(os.path.basename(ncFile))[0] 
    year = ncFileName[19:23] 
    month = ncFileName[24:26] 
    month = datetime.datetime(int(year),int(month),1).strftime('%B') 
    if previous: 
        previous = os.path.splitext(os.path.basename(previous))[0] 
        previousYear = previous[19:23] 
        previousMonth = previous[24:26] 
        previousMonth = datetime.datetime(int(previousYear),int(previousMonth),1).strftime('%B') 
        previous = previous + os.extsep + htmlExt 
    if next: 
        next = os.path.splitext(os.path.basename(next))[0] 
        nextYear = next[19:23] 
        nextMonth = next[24:26] 
        nextMonth = datetime.datetime(int(nextYear),int(nextMonth),1).strftime('%B') 
        next = next + os.extsep + htmlExt 
 
    nc = pycdf.CDF(ncFile) 
 
    t = nc.var('time')[:] 
    z = nc.var('z')[:] 
    u = nc.var('u')[:] 
    v = nc.var('v')[:] 
    w = nc.var('w')[:] 
 
    mu = np.ma.masked_invalid(u) 
    mv = np.ma.masked_invalid(v) 
    mw = np.ma.masked_invalid(w) 
 
    umean = mu.mean(axis=0).data 
    vmean = mv.mean(axis=0).data 
    wmean = mw.mean(axis=0).data 
 
    ucount = mu.count(axis=0) 
    vcount = mv.count(axis=0) 
    wcount = mw.count(axis=0) 
 
    fig = figure() 
    suptitle('Billy Mitchell Sodar :: ' + month + " " + year) 
 
    subplot(1,2,1) 
    plot(umean,z,label=r'$\bar{u}$') 
    plot(vmean,z,label=r'$\bar{v}$') 
    plot(wmean,z,label=r'$\bar{w}$') 
    legend(loc='best') 
    xlabel('Speed (cm/s)') 
    ylabel('Elevation (m)') 
    title('Average wind speeds') 
 
    subplot(1,2,2) 
    plot((ucount * 100.0)/float(mu.shape[0]),z,label=r'$\%\ samples(u|v)$') 
    plot((wcount * 100.0)/float(mw.shape[0]),z,label=r'$\%\ samples(w)$') 
    xticks(range(0,101,10)) 
    legend(loc='best') 
    xlabel('% of samples per month') 
    title('Number of valid samples') 
 
    outFile = os.path.join(pngDir,ncFileName + os.extsep + pngExt) 
    print 'Saving', outFile 
    fig.savefig(outFile) 
 
    htmlFile = os.path.join(pngDir,ncFileName + os.extsep + htmlExt) 
    html = html1 + month + " " + year 
    html = html + html2 + previous + html3 + next + html4 
    html = html + os.path.basename(outFile) + html5 
    handle = open(htmlFile,'w') 
    handle.write(html) 
    handle.close() 
 
    if first: 
        first = False 
        htmlFile = os.path.join(pngDir,"index" + os.extsep + htmlExt) 
        handle = open(htmlFile,'w') 
        handle.write(html) 
        handle.close() 
         
 
